def uwuize(beans):
	string_to_mod = beans
	string_to_mod = string_to_mod.replace("r", "w")
	string_to_mod = string_to_mod.replace("R", "W")
	string_to_mod = string_to_mod.replace("l", "w")
	string_to_mod = string_to_mod.replace("L", "W")
	return string_to_mod

uwuize("sorry")